/**
 * Copyright Kyndryl, Inc. 2023
 */
import { LitElement } from 'lit';
import { BUTTON_KINDS, BUTTON_SIZES, BUTTON_TYPES, BUTTON_ICON_POSITION } from './defs';
/**
 * Button component.
 *
 * @slot unnamed - Slot for button text.
 * @slot icon - Slot for an icon.
 * @fires on-click - Emits the original click event.
 */
export declare class Button extends LitElement {
    static styles: import("lit").CSSResultGroup[];
    /**
     * Associate the component with forms.
     * @ignore
     */
    static formAssociated: boolean;
    /**
     * Attached internals for form association.
     * @ignore
     */
    internals: ElementInternals;
    /** ARIA label for the button for accessibility. */
    description: string;
    /** Type for the &lt;button&gt; element. */
    type: BUTTON_TYPES;
    /** Specifies the visual appearance/kind of the button. */
    kind: BUTTON_KINDS;
    /** Converts the button to an &lt;a&gt; tag if specified. */
    href: string;
    /** Specifies the size of the button. */
    size: BUTTON_SIZES;
    /** Specifies the position of the icon relative to any button text. */
    iconPosition: BUTTON_ICON_POSITION;
    /** Determines if the button is disabled. */
    disabled: boolean;
    /** Determines if the button indicates a destructive action. */
    destructive: boolean;
    /** Queries default slot nodes.
     * @internal
     */
    _slottedEls: Array<any>;
    /** Queries icon slot nodes.
     * @internal
     */
    _iconEls: Array<any>;
    render(): import("lit-html").TemplateResult<1>;
    private handleClick;
    private _handleSlotChange;
    firstUpdated(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'kd-button': Button;
    }
}
//# sourceMappingURL=button.d.ts.map