import { LitElement } from 'lit';
import { LINK_TYPES, LINK_TARGETS } from './defs';
/**
 * Component for navigation links.
 * @fires on-click - Captures the click event and emits the original event details.
 * @slot unnamed - Slot for link text.
 * @slot icon - Slot for an icon.
 */
export declare class Link extends LitElement {
    static styles: import("lit").CSSResultGroup[];
    /** Link url. */
    href: string;
    /** Defines a target attribute for where to load the URL. Possible options include "_self" (deafult), "_blank", "_parent", "_top" */
    target: LINK_TARGETS;
    /** The Link type. Primary(App) or Secondary(Web).*/
    kind: LINK_TYPES;
    /** Defines a relationship between a linked resource and the document. An empty string (default) means no particular relationship */
    rel: string;
    /** Determines if the link is disabled.*/
    disabled: boolean;
    /** Whether you want the standalone Link. Bydefault false. Use this prop. (true) with icon with link variant. */
    standalone: boolean;
    render(): import("lit-html").TemplateResult<1>;
    private returnClassMap;
    private handleClick;
}
declare global {
    interface HTMLElementTagNameMap {
        'kd-link': Link;
    }
}
//# sourceMappingURL=link.d.ts.map